# nlpbaselines

Establish quick baselines for NLP tasks.

Citation:

```
@misc{hadoop,
  author={Wang Xiaoou},
  title={nlpbaselines: establish quick baselines for NLP tasks},
  year={2022},
  howpublished={\url{https://github.com/xiaoouwang/nlpbaselines}},
}
```

## How to use the package

## License

### Codes

`nlpbaselines` is licensed under Apache License 2.0. You can use `nlpbaselines` in your commercial products for free. We would appreciate it if you add a link to `nlpbaselines` on your website.

### Models

Unless otherwise specified, all models in `nlpbaselines` are licensed under [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/).